/****************************************************************************
** Meta object code from reading C++ file 'qmlpainterpath.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kquickimageeditor-0.6.1/src/annotations/qmlpainterpath.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlpainterpath.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QmlPainterPathE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlPainterPath::qt_create_metaobjectdata<qt_meta_tag_ZN14QmlPainterPathE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlPainterPath",
        "QML.Element",
        "auto",
        "QML.Foreign",
        "QPainterPath",
        "QML.Extended",
        "toString",
        "",
        "contains",
        "QPointF",
        "point",
        "QRectF",
        "rect",
        "intersects",
        "map",
        "QMatrix4x4",
        "transform",
        "mapBoundingRect",
        "svgPath",
        "empty",
        "elementCount",
        "start",
        "end",
        "boundingRect"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString() const>(6, 7, QMC::AccessPublic, QMetaType::QString),
        // Method 'contains'
        QtMocHelpers::MethodData<bool(const QPointF &) const>(8, 7, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'contains'
        QtMocHelpers::MethodData<bool(const QRectF &) const>(8, 7, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'intersects'
        QtMocHelpers::MethodData<bool(const QRectF &) const>(13, 7, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'map'
        QtMocHelpers::MethodData<QPainterPath(const QMatrix4x4 &) const>(14, 7, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'mapBoundingRect'
        QtMocHelpers::MethodData<QRectF(const QMatrix4x4 &) const>(17, 7, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'svgPath'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final),
        // property 'empty'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final),
        // property 'elementCount'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final),
        // property 'start'
        QtMocHelpers::PropertyData<QPointF>(21, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'end'
        QtMocHelpers::PropertyData<QPointF>(22, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'boundingRect'
        QtMocHelpers::PropertyData<QRectF>(23, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    0 },
    });
    return QtMocHelpers::metaObjectData<QmlPainterPath, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QmlPainterPath::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QmlPainterPathE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QmlPainterPathE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QmlPainterPathE_t>.metaTypes,
    nullptr
} };

void QmlPainterPath::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QmlPainterPath *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->contains((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->contains((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->intersects((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QPainterPath _r = _t->map((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPainterPath*>(_a[0]) = std::move(_r); }  break;
        case 5: { QRectF _r = _t->mapBoundingRect((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->svgPath(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->empty(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->elementCount(); break;
        case 3: *reinterpret_cast<QPointF*>(_v) = _t->start(); break;
        case 4: *reinterpret_cast<QPointF*>(_v) = _t->end(); break;
        case 5: *reinterpret_cast<QRectF*>(_v) = _t->boundingRect(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
