/****************************************************************************
** Meta object code from reading C++ file 'annotationviewport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kquickimageeditor-0.6.1/src/annotations/annotationviewport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'annotationviewport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18AnnotationViewportE_t {};
} // unnamed namespace

template <> constexpr inline auto AnnotationViewport::qt_create_metaobjectdata<qt_meta_tag_ZN18AnnotationViewportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AnnotationViewport",
        "QML.Element",
        "auto",
        "viewportRectChanged",
        "",
        "documentChanged",
        "hoverPositionChanged",
        "hoveredChanged",
        "pressPositionChanged",
        "pressedChanged",
        "anyPressedChanged",
        "hoveredMousePathChanged",
        "viewportRect",
        "QRectF",
        "document",
        "AnnotationDocument*",
        "hoverPosition",
        "QPointF",
        "hovered",
        "pressPosition",
        "pressed",
        "anyPressed",
        "hoveredMousePath",
        "QPainterPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewportRectChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoverPositionChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressPositionChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'anyPressedChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredMousePathChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'viewportRect'
        QtMocHelpers::PropertyData<QRectF>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'document'
        QtMocHelpers::PropertyData<AnnotationDocument*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'hoverPosition'
        QtMocHelpers::PropertyData<QPointF>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'hovered'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'pressPosition'
        QtMocHelpers::PropertyData<QPointF>(19, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'anyPressed'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'hoveredMousePath'
        QtMocHelpers::PropertyData<QPainterPath>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AnnotationViewport, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AnnotationViewport::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AnnotationViewportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AnnotationViewportE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AnnotationViewportE_t>.metaTypes,
    nullptr
} };

void AnnotationViewport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AnnotationViewport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewportRectChanged(); break;
        case 1: _t->documentChanged(); break;
        case 2: _t->hoverPositionChanged(); break;
        case 3: _t->hoveredChanged(); break;
        case 4: _t->pressPositionChanged(); break;
        case 5: _t->pressedChanged(); break;
        case 6: _t->anyPressedChanged(); break;
        case 7: _t->hoveredMousePathChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::viewportRectChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::documentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::hoverPositionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::hoveredChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::pressPositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::pressedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::anyPressedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationViewport::*)()>(_a, &AnnotationViewport::hoveredMousePathChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AnnotationDocument* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QRectF*>(_v) = _t->viewportRect(); break;
        case 1: *reinterpret_cast<AnnotationDocument**>(_v) = _t->document(); break;
        case 2: *reinterpret_cast<QPointF*>(_v) = _t->hoverPosition(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isHovered(); break;
        case 4: *reinterpret_cast<QPointF*>(_v) = _t->pressPosition(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPressed(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isAnyPressed(); break;
        case 7: *reinterpret_cast<QPainterPath*>(_v) = _t->hoveredMousePath(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setViewportRect(*reinterpret_cast<QRectF*>(_v)); break;
        case 1: _t->setDocument(*reinterpret_cast<AnnotationDocument**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AnnotationViewport::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AnnotationViewport::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AnnotationViewportE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int AnnotationViewport::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void AnnotationViewport::viewportRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AnnotationViewport::documentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AnnotationViewport::hoverPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AnnotationViewport::hoveredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AnnotationViewport::pressPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AnnotationViewport::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AnnotationViewport::anyPressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AnnotationViewport::hoveredMousePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
