/****************************************************************************
** Meta object code from reading C++ file 'utils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kquickimageeditor-0.6.1/src/annotations/utils.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'utils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5UtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto Utils::qt_create_metaobjectdata<qt_meta_tag_ZN5UtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Utils",
        "QML.Singleton",
        "true",
        "QML.Element",
        "auto",
        "dprRound",
        "",
        "value",
        "dpr",
        "QPointF",
        "QVector2D",
        "rectScaled",
        "QRectF",
        "rect",
        "factor",
        "rectNormalized",
        "rectClipped",
        "clipRect",
        "rectAspectRatioedForHandle",
        "ratio",
        "edges",
        "rectAspectRatioed",
        "clamp",
        "min",
        "max",
        "combinedScale",
        "QMatrix4x4",
        "matrix",
        "sceneToDocumentPoint",
        "point",
        "AnnotationViewport*",
        "viewport",
        "handleResizeProperties",
        "QVariantMap",
        "dx",
        "dy",
        "AnnotationDocument*",
        "document"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'dprRound'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(5, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 7 }, { QMetaType::QReal, 8 },
        }}),
        // Method 'dprRound'
        QtMocHelpers::MethodData<QPointF(const QPointF &, qreal)>(5, 6, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 7 }, { QMetaType::QReal, 8 },
        }}),
        // Method 'dprRound'
        QtMocHelpers::MethodData<QVector2D(const QVector2D &, qreal)>(5, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 7 }, { QMetaType::QReal, 8 },
        }}),
        // Method 'rectScaled'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal)>(11, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QReal, 14 },
        }}),
        // Method 'rectNormalized'
        QtMocHelpers::MethodData<QRectF(const QRectF &)>(15, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'rectClipped'
        QtMocHelpers::MethodData<QRectF(const QRectF &, const QRectF &)>(16, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 17 },
        }}),
        // Method 'rectAspectRatioedForHandle'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal, int)>(18, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QReal, 19 }, { QMetaType::Int, 20 },
        }}),
        // Method 'rectAspectRatioed'
        QtMocHelpers::MethodData<QRectF(const QRectF &, qreal)>(21, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QReal, 19 },
        }}),
        // Method 'clamp'
        QtMocHelpers::MethodData<qreal(qreal, qreal, qreal)>(22, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 7 }, { QMetaType::QReal, 23 }, { QMetaType::QReal, 24 },
        }}),
        // Method 'clamp'
        QtMocHelpers::MethodData<qreal(qreal, qreal)>(22, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QReal, {{
            { QMetaType::QReal, 7 }, { QMetaType::QReal, 23 },
        }}),
        // Method 'clamp'
        QtMocHelpers::MethodData<qreal(qreal)>(22, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QReal, {{
            { QMetaType::QReal, 7 },
        }}),
        // Method 'combinedScale'
        QtMocHelpers::MethodData<qreal(const QMatrix4x4 &)>(25, 6, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Method 'sceneToDocumentPoint'
        QtMocHelpers::MethodData<QPointF(QPointF, AnnotationViewport *)>(28, 6, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Method 'handleResizeProperties'
        QtMocHelpers::MethodData<QVariantMap(qreal, qreal, int, AnnotationDocument *)>(32, 6, QMC::AccessPublic, 0x80000000 | 33, {{
            { QMetaType::QReal, 34 }, { QMetaType::QReal, 35 }, { QMetaType::Int, 20 }, { 0x80000000 | 36, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Utils, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Utils::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5UtilsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5UtilsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5UtilsE_t>.metaTypes,
    nullptr
} };

void Utils::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Utils *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { qreal _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 1: { QPointF _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVector2D _r = _t->dprRound((*reinterpret_cast<std::add_pointer_t<QVector2D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVector2D*>(_a[0]) = std::move(_r); }  break;
        case 3: { QRectF _r = _t->rectScaled((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 4: { QRectF _r = _t->rectNormalized((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 5: { QRectF _r = _t->rectClipped((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 6: { QRectF _r = _t->rectAspectRatioedForHandle((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 7: { QRectF _r = _t->rectAspectRatioed((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 8: { qreal _r = _t->clamp((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 9: { qreal _r = _t->clamp((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 10: { qreal _r = _t->clamp((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 11: { qreal _r = _t->combinedScale((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 12: { QPointF _r = _t->sceneToDocumentPoint((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AnnotationViewport*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVariantMap _r = _t->handleResizeProperties((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<AnnotationDocument*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AnnotationViewport* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AnnotationDocument* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Utils::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Utils::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5UtilsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Utils::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
