/****************************************************************************
** Meta object code from reading C++ file 'annotationdocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kquickimageeditor-0.6.1/src/annotations/annotationdocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'annotationdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18AnnotationDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto AnnotationDocument::qt_create_metaobjectdata<qt_meta_tag_ZN18AnnotationDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AnnotationDocument",
        "QML.Element",
        "auto",
        "selectedItemWrapperChanged",
        "",
        "undoStackDepthChanged",
        "redoStackDepthChanged",
        "canvasRectChanged",
        "imageSizeChanged",
        "imageDprChanged",
        "transformChanged",
        "modifiedChanged",
        "repaintNeeded",
        "AnnotationDocument::RepaintTypes",
        "types",
        "setBaseImage",
        "path",
        "QUrl",
        "localFile",
        "cropCanvas",
        "QRectF",
        "cropRect",
        "applyTransform",
        "QMatrix4x4",
        "matrix",
        "clearAnnotations",
        "clear",
        "saveImage",
        "undo",
        "redo",
        "selectItem",
        "rect",
        "deselectItem",
        "deleteSelectedItem",
        "tool",
        "AnnotationTool*",
        "selectedItem",
        "SelectedItemWrapper*",
        "redoStackDepth",
        "undoStackDepth",
        "canvasRect",
        "imageSize",
        "QSizeF",
        "imageDpr",
        "transform",
        "renderTransform",
        "inputTransform",
        "modified",
        "ContinueOption",
        "NoOptions",
        "Snap",
        "CenterResize",
        "RepaintType",
        "NoTypes",
        "BaseImage",
        "Annotations",
        "All"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectedItemWrapperChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoStackDepthChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redoStackDepthChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canvasRectChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageSizeChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageDprChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transformChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void(AnnotationDocument::RepaintTypes)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'setBaseImage'
        QtMocHelpers::MethodData<void(const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'setBaseImage'
        QtMocHelpers::MethodData<void(const QUrl &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'cropCanvas'
        QtMocHelpers::MethodData<void(const QRectF &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'applyTransform'
        QtMocHelpers::MethodData<void(const QMatrix4x4 &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Method 'clearAnnotations'
        QtMocHelpers::MethodData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'saveImage'
        QtMocHelpers::MethodData<bool(const QString &) const>(27, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'undo'
        QtMocHelpers::MethodData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'redo'
        QtMocHelpers::MethodData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'selectItem'
        QtMocHelpers::MethodData<void(const QRectF &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 31 },
        }}),
        // Method 'deselectItem'
        QtMocHelpers::MethodData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'deleteSelectedItem'
        QtMocHelpers::MethodData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tool'
        QtMocHelpers::PropertyData<AnnotationTool*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'selectedItem'
        QtMocHelpers::PropertyData<SelectedItemWrapper*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'redoStackDepth'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'undoStackDepth'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'canvasRect'
        QtMocHelpers::PropertyData<QRectF>(40, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'imageSize'
        QtMocHelpers::PropertyData<QSizeF>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'imageDpr'
        QtMocHelpers::PropertyData<qreal>(43, QMetaType::QReal, QMC::DefaultPropertyFlags, 5),
        // property 'transform'
        QtMocHelpers::PropertyData<QMatrix4x4>(44, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'renderTransform'
        QtMocHelpers::PropertyData<QMatrix4x4>(45, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'inputTransform'
        QtMocHelpers::PropertyData<QMatrix4x4>(46, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'modified'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ContinueOption'
        QtMocHelpers::EnumData<enum ContinueOption>(48, 48, QMC::EnumIsScoped).add({
            {   49, ContinueOption::NoOptions },
            {   50, ContinueOption::Snap },
            {   51, ContinueOption::CenterResize },
        }),
        // enum 'RepaintType'
        QtMocHelpers::EnumData<enum RepaintType>(52, 52, QMC::EnumIsScoped).add({
            {   53, RepaintType::NoTypes },
            {   54, RepaintType::BaseImage },
            {   55, RepaintType::Annotations },
            {   56, RepaintType::All },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AnnotationDocument, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AnnotationDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AnnotationDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AnnotationDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AnnotationDocumentE_t>.metaTypes,
    nullptr
} };

void AnnotationDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AnnotationDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectedItemWrapperChanged(); break;
        case 1: _t->undoStackDepthChanged(); break;
        case 2: _t->redoStackDepthChanged(); break;
        case 3: _t->canvasRectChanged(); break;
        case 4: _t->imageSizeChanged(); break;
        case 5: _t->imageDprChanged(); break;
        case 6: _t->transformChanged(); break;
        case 7: _t->modifiedChanged(); break;
        case 8: _t->repaintNeeded((*reinterpret_cast<std::add_pointer_t<AnnotationDocument::RepaintTypes>>(_a[1]))); break;
        case 9: _t->setBaseImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setBaseImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->cropCanvas((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 12: _t->applyTransform((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1]))); break;
        case 13: _t->clearAnnotations(); break;
        case 14: _t->clear(); break;
        case 15: { bool _r = _t->saveImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->undo(); break;
        case 17: _t->redo(); break;
        case 18: _t->selectItem((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 19: _t->deselectItem(); break;
        case 20: _t->deleteSelectedItem(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::selectedItemWrapperChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::undoStackDepthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::redoStackDepthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::canvasRectChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::imageSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::imageDprChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::transformChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)()>(_a, &AnnotationDocument::modifiedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationDocument::*)(AnnotationDocument::RepaintTypes )>(_a, &AnnotationDocument::repaintNeeded, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AnnotationTool* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SelectedItemWrapper* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AnnotationTool**>(_v) = _t->tool(); break;
        case 1: *reinterpret_cast<SelectedItemWrapper**>(_v) = _t->selectedItemWrapper(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->redoStackDepth(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->undoStackDepth(); break;
        case 4: *reinterpret_cast<QRectF*>(_v) = _t->canvasRect(); break;
        case 5: *reinterpret_cast<QSizeF*>(_v) = _t->imageSize(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->imageDpr(); break;
        case 7: *reinterpret_cast<QMatrix4x4*>(_v) = _t->transform(); break;
        case 8: *reinterpret_cast<QMatrix4x4*>(_v) = _t->renderTransform(); break;
        case 9: *reinterpret_cast<QMatrix4x4*>(_v) = _t->inputTransform(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isModified(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 10: _t->setModified(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AnnotationDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AnnotationDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AnnotationDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AnnotationDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void AnnotationDocument::selectedItemWrapperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AnnotationDocument::undoStackDepthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AnnotationDocument::redoStackDepthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AnnotationDocument::canvasRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AnnotationDocument::imageSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AnnotationDocument::imageDprChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AnnotationDocument::transformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AnnotationDocument::modifiedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AnnotationDocument::repaintNeeded(AnnotationDocument::RepaintTypes _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN19SelectedItemWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto SelectedItemWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN19SelectedItemWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SelectedItemWrapper",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Created by AnnotationDocument",
        "strokeWidthChanged",
        "",
        "strokeColorChanged",
        "fillColorChanged",
        "strengthChanged",
        "fontChanged",
        "fontColorChanged",
        "numberChanged",
        "textChanged",
        "shadowChanged",
        "geometryPathChanged",
        "mousePathChanged",
        "transformChanged",
        "applyTransform",
        "QMatrix4x4",
        "matrix",
        "commitChanges",
        "hasSelection",
        "options",
        "AnnotationTool::Options",
        "strokeWidth",
        "strokeColor",
        "QColor",
        "fillColor",
        "strength",
        "font",
        "QFont",
        "fontColor",
        "number",
        "text",
        "shadow",
        "geometryPath",
        "QPainterPath",
        "mousePath",
        "transform"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'strokeWidthChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'strokeColorChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillColorChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'strengthChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontColorChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'numberChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryPathChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mousePathChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transformChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'applyTransform'
        QtMocHelpers::MethodData<void(const QMatrix4x4 &)>(20, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Method 'commitChanges'
        QtMocHelpers::MethodData<bool()>(23, 8, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasSelection'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'options'
        QtMocHelpers::PropertyData<AnnotationTool::Options>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'strokeWidth'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'strokeColor'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'fillColor'
        QtMocHelpers::PropertyData<QColor>(30, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'strength'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'fontColor'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'number'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'shadow'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'geometryPath'
        QtMocHelpers::PropertyData<QPainterPath>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'mousePath'
        QtMocHelpers::PropertyData<QPainterPath>(40, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'transform'
        QtMocHelpers::PropertyData<QMatrix4x4>(41, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<SelectedItemWrapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN19SelectedItemWrapperE[] = {
    QMetaObject::SuperData::link<AnnotationTool::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject SelectedItemWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SelectedItemWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SelectedItemWrapperE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN19SelectedItemWrapperE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19SelectedItemWrapperE_t>.metaTypes,
    nullptr
} };

void SelectedItemWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SelectedItemWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->strokeWidthChanged(); break;
        case 1: _t->strokeColorChanged(); break;
        case 2: _t->fillColorChanged(); break;
        case 3: _t->strengthChanged(); break;
        case 4: _t->fontChanged(); break;
        case 5: _t->fontColorChanged(); break;
        case 6: _t->numberChanged(); break;
        case 7: _t->textChanged(); break;
        case 8: _t->shadowChanged(); break;
        case 9: _t->geometryPathChanged(); break;
        case 10: _t->mousePathChanged(); break;
        case 11: _t->transformChanged(); break;
        case 12: _t->applyTransform((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1]))); break;
        case 13: { bool _r = _t->commitChanges();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::strokeWidthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::strokeColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::fillColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::strengthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::fontChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::fontColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::numberChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::textChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::shadowChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::geometryPathChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::mousePathChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectedItemWrapper::*)()>(_a, &SelectedItemWrapper::transformChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hasSelection(); break;
        case 1: *reinterpret_cast<AnnotationTool::Options*>(_v) = _t->options(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->strokeWidth(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->strokeColor(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->fillColor(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->strength(); break;
        case 6: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->fontColor(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->number(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasShadow(); break;
        case 11: *reinterpret_cast<QPainterPath*>(_v) = _t->geometryPath(); break;
        case 12: *reinterpret_cast<QPainterPath*>(_v) = _t->mousePath(); break;
        case 13: *reinterpret_cast<QMatrix4x4*>(_v) = _t->transform(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setStrokeWidth(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setStrokeColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setFillColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setStrength(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 7: _t->setFontColor(*reinterpret_cast<QColor*>(_v)); break;
        case 8: _t->setNumber(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setShadow(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SelectedItemWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SelectedItemWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SelectedItemWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SelectedItemWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void SelectedItemWrapper::strokeWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SelectedItemWrapper::strokeColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SelectedItemWrapper::fillColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SelectedItemWrapper::strengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SelectedItemWrapper::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SelectedItemWrapper::fontColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SelectedItemWrapper::numberChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SelectedItemWrapper::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SelectedItemWrapper::shadowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SelectedItemWrapper::geometryPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void SelectedItemWrapper::mousePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void SelectedItemWrapper::transformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
