/****************************************************************************
** Meta object code from reading C++ file 'annotationtool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kquickimageeditor-0.6.1/src/annotations/annotationtool.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'annotationtool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AnnotationToolE_t {};
} // unnamed namespace

template <> constexpr inline auto AnnotationTool::qt_create_metaobjectdata<qt_meta_tag_ZN14AnnotationToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AnnotationTool",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Created by AnnotationDocument",
        "typeChanged",
        "",
        "optionsChanged",
        "strokeWidthChanged",
        "width",
        "strokeColorChanged",
        "QColor",
        "color",
        "fillColorChanged",
        "strengthChanged",
        "strength",
        "fontChanged",
        "QFont",
        "font",
        "fontColorChanged",
        "numberChanged",
        "number",
        "shadowChanged",
        "hasShadow",
        "geometryChanged",
        "QRectF",
        "rect",
        "aspectRatioChanged",
        "ratio",
        "type",
        "Tool",
        "isNoTool",
        "isMetaTool",
        "isCreationTool",
        "options",
        "Options",
        "strokeWidth",
        "strokeColor",
        "fillColor",
        "fontColor",
        "shadow",
        "geometry",
        "aspectRatio",
        "NoTool",
        "CropTool",
        "SelectTool",
        "FreehandTool",
        "HighlighterTool",
        "LineTool",
        "ArrowTool",
        "RectangleTool",
        "EllipseTool",
        "BlurTool",
        "PixelateTool",
        "TextTool",
        "NumberTool",
        "NTools",
        "Option",
        "NoOptions",
        "StrokeOption",
        "FillOption",
        "StrengthOption",
        "FontOption",
        "TextOption",
        "NumberOption",
        "ShadowOption",
        "GeometryOption",
        "AspectRatioOption",
        "TranslateOption",
        "ResizeOption",
        "RotateOption",
        "TransformOption"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'optionsChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'strokeWidthChanged'
        QtMocHelpers::SignalData<void(int)>(10, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'strokeColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'fillColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'strengthChanged'
        QtMocHelpers::SignalData<void(qreal)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 17 },
        }}),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'fontColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(21, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'numberChanged'
        QtMocHelpers::SignalData<void(const int)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Signal 'shadowChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(26, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'aspectRatioChanged'
        QtMocHelpers::SignalData<void(qreal)>(29, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum Tool>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'isNoTool'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'isMetaTool'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'isCreationTool'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'options'
        QtMocHelpers::PropertyData<Options>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'strokeWidth'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 2),
        // property 'strokeColor'
        QtMocHelpers::PropertyData<QColor>(39, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'fillColor'
        QtMocHelpers::PropertyData<QColor>(40, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'strength'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 5),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'fontColor'
        QtMocHelpers::PropertyData<QColor>(41, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'number'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 8),
        // property 'shadow'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 9),
        // property 'geometry'
        QtMocHelpers::PropertyData<QRectF>(43, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'aspectRatio'
        QtMocHelpers::PropertyData<qreal>(44, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Tool'
        QtMocHelpers::EnumData<enum Tool>(32, 32, QMC::EnumFlags{}).add({
            {   45, Tool::NoTool },
            {   46, Tool::CropTool },
            {   47, Tool::SelectTool },
            {   48, Tool::FreehandTool },
            {   49, Tool::HighlighterTool },
            {   50, Tool::LineTool },
            {   51, Tool::ArrowTool },
            {   52, Tool::RectangleTool },
            {   53, Tool::EllipseTool },
            {   54, Tool::BlurTool },
            {   55, Tool::PixelateTool },
            {   56, Tool::TextTool },
            {   57, Tool::NumberTool },
            {   58, Tool::NTools },
        }),
        // flag 'Options'
        QtMocHelpers::EnumData<Options>(37, 59, QMC::EnumIsFlag).add({
            {   60, Option::NoOptions },
            {   61, Option::StrokeOption },
            {   62, Option::FillOption },
            {   63, Option::StrengthOption },
            {   64, Option::FontOption },
            {   65, Option::TextOption },
            {   66, Option::NumberOption },
            {   67, Option::ShadowOption },
            {   68, Option::GeometryOption },
            {   69, Option::AspectRatioOption },
            {   70, Option::TranslateOption },
            {   71, Option::ResizeOption },
            {   72, Option::RotateOption },
            {   73, Option::TransformOption },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AnnotationTool, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AnnotationTool::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AnnotationToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AnnotationToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AnnotationToolE_t>.metaTypes,
    nullptr
} };

void AnnotationTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AnnotationTool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged(); break;
        case 1: _t->optionsChanged(); break;
        case 2: _t->strokeWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->strokeColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->fillColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->strengthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 6: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 7: _t->fontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 8: _t->numberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->shadowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->geometryChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 11: _t->aspectRatioChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)()>(_a, &AnnotationTool::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)()>(_a, &AnnotationTool::optionsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(int )>(_a, &AnnotationTool::strokeWidthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(const QColor & )>(_a, &AnnotationTool::strokeColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(const QColor & )>(_a, &AnnotationTool::fillColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(qreal )>(_a, &AnnotationTool::strengthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(const QFont & )>(_a, &AnnotationTool::fontChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(const QColor & )>(_a, &AnnotationTool::fontColorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(const int )>(_a, &AnnotationTool::numberChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(bool )>(_a, &AnnotationTool::shadowChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(const QRectF & )>(_a, &AnnotationTool::geometryChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotationTool::*)(qreal )>(_a, &AnnotationTool::aspectRatioChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Tool*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isNoTool(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isMetaTool(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isCreationTool(); break;
        case 4: QtMocHelpers::assignFlags<Options>(_v, _t->options()); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->strokeWidth(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->strokeColor(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->fillColor(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->strength(); break;
        case 9: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->fontColor(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->number(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->hasShadow(); break;
        case 13: *reinterpret_cast<QRectF*>(_v) = _t->geometry(); break;
        case 14: *reinterpret_cast<qreal*>(_v) = _t->aspectRatio(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<enum Tool*>(_v)); break;
        case 5: _t->setStrokeWidth(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setStrokeColor(*reinterpret_cast<QColor*>(_v)); break;
        case 7: _t->setFillColor(*reinterpret_cast<QColor*>(_v)); break;
        case 8: _t->setStrength(*reinterpret_cast<qreal*>(_v)); break;
        case 9: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 10: _t->setFontColor(*reinterpret_cast<QColor*>(_v)); break;
        case 11: _t->setNumber(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setShadow(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setGeometry(*reinterpret_cast<QRectF*>(_v)); break;
        case 14: _t->setAspectRatio(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetType(); break;
        case 5: _t->resetStrokeWidth(); break;
        case 6: _t->resetStrokeColor(); break;
        case 7: _t->resetFillColor(); break;
        case 8: _t->resetStrength(); break;
        case 9: _t->resetFont(); break;
        case 10: _t->resetFontColor(); break;
        case 11: _t->resetNumber(); break;
        case 12: _t->resetShadow(); break;
        case 13: _t->resetGeometry(); break;
        case 14: _t->resetAspectRatio(); break;
        default: break;
        }
    }
}

const QMetaObject *AnnotationTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AnnotationTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AnnotationToolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AnnotationTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void AnnotationTool::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AnnotationTool::optionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AnnotationTool::strokeWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AnnotationTool::strokeColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AnnotationTool::fillColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AnnotationTool::strengthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AnnotationTool::fontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AnnotationTool::fontColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AnnotationTool::numberChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void AnnotationTool::shadowChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AnnotationTool::geometryChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void AnnotationTool::aspectRatioChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
