/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<annotationconfig.h>)
#  include <annotationconfig.h>
#endif
#if __has_include(<annotationdocument.h>)
#  include <annotationdocument.h>
#endif
#if __has_include(<annotationtool.h>)
#  include <annotationtool.h>
#endif
#if __has_include(<annotationviewport.h>)
#  include <annotationviewport.h>
#endif
#if __has_include(<imagedocument.h>)
#  include <imagedocument.h>
#endif
#if __has_include(<imageitem.h>)
#  include <imageitem.h>
#endif
#if __has_include(<qmlpainterpath.h>)
#  include <qmlpainterpath.h>
#endif
#if __has_include(<resizehandle.h>)
#  include <resizehandle.h>
#endif
#if __has_include(<resizerectangle.h>)
#  include <resizerectangle.h>
#endif
#if __has_include(<utils.h>)
#  include <utils.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kquickimageeditor()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AnnotationConfig>("org.kde.kquickimageeditor", 1);
    qmlRegisterTypesAndRevisions<AnnotationDocument>("org.kde.kquickimageeditor", 1);
    qmlRegisterEnum<AnnotationDocument::ContinueOption>("AnnotationDocument::ContinueOption");
    qmlRegisterEnum<AnnotationDocument::RepaintType>("AnnotationDocument::RepaintType");
    qmlRegisterTypesAndRevisions<AnnotationTool>("org.kde.kquickimageeditor", 1);
    qmlRegisterEnum<AnnotationTool::Tool>("AnnotationTool::Tool");
    qmlRegisterEnum<AnnotationTool::Options>("AnnotationTool::Options");
    qmlRegisterEnum<AnnotationTool::Option>("AnnotationTool::Option");
    qmlRegisterTypesAndRevisions<AnnotationViewport>("org.kde.kquickimageeditor", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.kquickimageeditor", 1);
    qmlRegisterTypesAndRevisions<ImageDocument>("org.kde.kquickimageeditor", 1);
    qmlRegisterTypesAndRevisions<ImageItem>("org.kde.kquickimageeditor", 1);
    qmlRegisterEnum<ImageItem::FillMode>("ImageItem::FillMode");
    qmlRegisterTypesAndRevisions<QmlPainterPath>("org.kde.kquickimageeditor", 1);
    qmlRegisterTypesAndRevisions<ResizeHandle>("org.kde.kquickimageeditor", 1);
    qmlRegisterEnum<ResizeHandle::Corner>("ResizeHandle::Corner");
    qmlRegisterTypesAndRevisions<ResizeRectangle>("org.kde.kquickimageeditor", 1);
    qmlRegisterTypesAndRevisions<SelectedItemWrapper>("org.kde.kquickimageeditor", 1);
    qmlRegisterTypesAndRevisions<Utils>("org.kde.kquickimageeditor", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kquickimageeditor", 1, 0);
}

static const QQmlModuleRegistration orgkdekquickimageeditorRegistration("org.kde.kquickimageeditor", qml_register_types_org_kde_kquickimageeditor);
